@@ -18,7 +18,7 @@ use vars qw($VERSION @ISA @EXPORT) ;
 
 @ISA = qw(Exporter DynaLoader);
 @EXPORT = qw( filter_add filter_del filter_read filter_read_exact) ;
-$VERSION = "1.48" ;
+$VERSION = "1.50" ;
 
 sub filter_read_exact($)
 {
@@ -48,9 +48,9 @@ sub filter_add($)
     my $coderef = (ref $obj eq 'CODE') ;
 
     # If the parameter isn't already a reference, make it one.
-    $obj = \$obj unless ref $obj ;
-
-    $obj = bless ($obj, (caller)[0]) unless $coderef ;
+    if (!$coderef and !ref $obj) {
+      $obj = bless (\$obj, (caller)[0]);
+    }
 
     # finish off the installation of the filter in C.
     Filter::Util::Call::real_import($obj, (caller)[0], $coderef) ;
@@ -182,7 +182,7 @@ will result in the C<@_> array having the following values:
 Before terminating, the C<import> function must explicitly install the
 filter by calling C<filter_add>.
 
-B<filter_add()>
+=head2 B<filter_add()>
 
 The function, C<filter_add>, actually installs the filter. It takes one
 parameter which should be a reference. The kind of reference used will
@@ -193,7 +193,7 @@ If a CODE reference is used then a I<closure filter> will be assumed.
 If a CODE reference is not used, a I<method filter> will be assumed.
 In a I<method filter>, the reference can be used to store context
 information. The reference will be I<blessed> into the package by
-C<filter_add>.
+C<filter_add>, unless the reference was already blessed.
 
 See the filters at the end of this documents for examples of using
 context information using both I<method filters> and I<closure
@@ -287,6 +287,11 @@ to call filter any more.
 
 See L<Example 4: Using filter_del> for details.
 
+=item I<real_import>
+
+Internal function which adds the filter, based on the L<filter_add>
+argument type.
+
 =back
 
 =head1 EXAMPLES
@@ -493,5 +498,12 @@ Paul Marquess
 
 26th January 1996
 
+=head1 LICENSE
+
+Copyright (c) 1995-2011 Paul Marquess. All rights reserved.
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
 =cut
 
